@@ -7,7 +7,7 @@ import re
 import string
 from abc import ABC, abstractmethod
 from copy import deepcopy
-from typing import Optional, Type
+from typing import Type
 from uuid import UUID
 
 from pycloudlib import (
@@ -28,6 +28,7 @@ import cloudinit
 from cloudinit.subp import ProcessExecutionError, subp
 from tests.integration_tests import integration_settings
 from tests.integration_tests.instances import IntegrationInstance
+from tests.integration_tests.releases import CURRENT_RELEASE
 from tests.integration_tests.util import emit_dots_on_travis
 
 log = logging.getLogger("integration_testing")
@@ -46,52 +47,6 @@ def _get_ubuntu_series() -> list:
     return out.splitlines()
 
 
-class ImageSpecification:
-    """A specification of an image to launch for testing.
-
-    If either of ``os`` and ``release`` are not specified, an attempt will be
-    made to infer the correct values for these on instantiation.
-
-    :param image_id:
-        The image identifier used by the rest of the codebase to launch this
-        image.
-    :param os:
-        An optional string describing the operating system this image is for
-        (e.g.  "ubuntu", "rhel", "freebsd").
-    :param release:
-        A optional string describing the operating system release (e.g.
-        "focal", "8"; the exact values here will depend on the OS).
-    """
-
-    def __init__(
-        self,
-        image_id: str,
-        os: Optional[str] = None,
-        release: Optional[str] = None,
-    ):
-        if image_id in _get_ubuntu_series():
-            if os is None:
-                os = "ubuntu"
-            if release is None:
-                release = image_id
-
-        self.image_id = image_id
-        self.os = os
-        self.release = release
-        log.info(
-            "Detected image: image_id=%s os=%s release=%s",
-            self.image_id,
-            self.os,
-            self.release,
-        )
-
-    @classmethod
-    def from_os_image(cls):
-        """Return an ImageSpecification for integration_settings.OS_IMAGE."""
-        parts = integration_settings.OS_IMAGE.split("::", 2)
-        return cls(*parts)
-
-
 class IntegrationCloud(ABC):
     datasource: str
     cloud_instance: BaseCloud
@@ -127,12 +82,9 @@ class IntegrationCloud(ABC):
         raise NotImplementedError
 
     def _get_initial_image(self, **kwargs) -> str:
-        image = ImageSpecification.from_os_image()
-        try:
-            return self.cloud_instance.daily_image(image.image_id, **kwargs)
-        except (ValueError, IndexError) as ex:
-            log.debug("Exception while executing `daily_image`: %s", ex)
-            return image.image_id
+        return CURRENT_RELEASE.image_id or self.cloud_instance.daily_image(
+            CURRENT_RELEASE.series, **kwargs
+        )
 
     def _perform_launch(self, launch_kwargs, **kwargs) -> BaseInstance:
         pycloudlib_instance = self.cloud_instance.launch(**launch_kwargs)
@@ -398,17 +350,16 @@ class OpenstackCloud(IntegrationCloud):
         )
 
     def _get_initial_image(self, **kwargs):
-        image = ImageSpecification.from_os_image()
         try:
-            UUID(image.image_id)
+            UUID(CURRENT_RELEASE.image_id)
         except ValueError as e:
-            raise Exception(
+            raise RuntimeError(
                 "When using Openstack, `OS_IMAGE` MUST be specified with "
                 "a 36-character UUID image ID. Passing in a release name is "
                 "not valid here.\n"
-                "OS image id: {}".format(image.image_id)
+                "OS image id: {}".format(CURRENT_RELEASE.image_id)
             ) from e
-        return image.image_id
+        return CURRENT_RELEASE.image_id
 
 
 class IbmCloud(IntegrationCloud):
