@@ -3,7 +3,6 @@
 """ test_handler_apt_configure_sources_list
 Test templating of sources list
 """
-import logging
 import os
 import shutil
 import tempfile
@@ -15,8 +14,6 @@ from cloudinit.distros.debian import Distro
 from tests.unittests import helpers as t_help
 from tests.unittests.util import get_cloud
 
-LOG = logging.getLogger(__name__)
-
 YAML_TEXT_CUSTOM_SL = """
 apt_mirror: http://archive.ubuntu.com/ubuntu/
 apt_custom_sources_list: |
@@ -97,9 +94,7 @@ class TestAptSourceConfigSourceList(t_help.FilesystemMockingTestCase):
                         templater, "render_string", return_value="fake"
                     ) as mockrnd:
                         with mock.patch.object(util, "rename"):
-                            cc_apt_configure.handle(
-                                "test", cfg, mycloud, LOG, None
-                            )
+                            cc_apt_configure.handle("test", cfg, mycloud, None)
 
         mockisfile.assert_any_call(
             "/etc/cloud/templates/sources.list.%s.tmpl" % distro
@@ -135,7 +130,7 @@ class TestAptSourceConfigSourceList(t_help.FilesystemMockingTestCase):
     @staticmethod
     def myresolve(name):
         """Fake util.is_resolvable for mirrorfail tests"""
-        if name == "does.not.exist":
+        if "does.not.exist" in name:
             print("Faking FAIL for '%s'" % name)
             return False
         else:
@@ -155,8 +150,8 @@ class TestAptSourceConfigSourceList(t_help.FilesystemMockingTestCase):
                 ],
                 "http://httpredir.debian.org/debian",
             )
-        mockresolve.assert_any_call("does.not.exist")
-        mockresolve.assert_any_call("httpredir.debian.org")
+        mockresolve.assert_any_call("http://does.not.exist")
+        mockresolve.assert_any_call("http://httpredir.debian.org/debian")
 
     def test_apt_v1_srcl_ubuntu_mirrorfail(self):
         """Test rendering of a source.list from template for ubuntu"""
@@ -168,8 +163,8 @@ class TestAptSourceConfigSourceList(t_help.FilesystemMockingTestCase):
                 ["http://does.not.exist", "http://archive.ubuntu.com/ubuntu/"],
                 "http://archive.ubuntu.com/ubuntu/",
             )
-        mockresolve.assert_any_call("does.not.exist")
-        mockresolve.assert_any_call("archive.ubuntu.com")
+        mockresolve.assert_any_call("http://does.not.exist")
+        mockresolve.assert_any_call("http://archive.ubuntu.com/ubuntu/")
 
     def test_apt_v1_srcl_custom(self):
         """Test rendering from a custom source.list template"""
@@ -182,9 +177,7 @@ class TestAptSourceConfigSourceList(t_help.FilesystemMockingTestCase):
                 with mock.patch.object(
                     Distro, "get_primary_arch", return_value="amd64"
                 ):
-                    cc_apt_configure.handle(
-                        "notimportant", cfg, mycloud, LOG, None
-                    )
+                    cc_apt_configure.handle("notimportant", cfg, mycloud, None)
 
         mockwrite.assert_called_once_with(
             "/etc/apt/sources.list", EXPECTED_CONVERTED_CONTENT, mode=420
