@@ -64,7 +64,7 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.mock_existence_of_disk(disk_path)
         self.assertEqual(
             disk_path,
-            cc_mounts.sanitize_devname(disk_path, lambda x: None, mock.Mock()),
+            cc_mounts.sanitize_devname(disk_path, lambda x: None),
         )
 
     def test_existent_disk_name_returns_full_path(self):
@@ -73,7 +73,7 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.mock_existence_of_disk(disk_path)
         self.assertEqual(
             disk_path,
-            cc_mounts.sanitize_devname(disk_name, lambda x: None, mock.Mock()),
+            cc_mounts.sanitize_devname(disk_name, lambda x: None),
         )
 
     def test_existent_meta_disk_is_returned(self):
@@ -82,7 +82,8 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.assertEqual(
             actual_disk_path,
             cc_mounts.sanitize_devname(
-                "ephemeral0", lambda x: actual_disk_path, mock.Mock()
+                "ephemeral0",
+                lambda x: actual_disk_path,
             ),
         )
 
@@ -93,7 +94,8 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.assertEqual(
             actual_partition_path,
             cc_mounts.sanitize_devname(
-                "ephemeral0.1", lambda x: disk_name, mock.Mock()
+                "ephemeral0.1",
+                lambda x: disk_name,
             ),
         )
 
@@ -104,7 +106,8 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.assertEqual(
             actual_partition_path,
             cc_mounts.sanitize_devname(
-                "ephemeral0.1", lambda x: disk_name, mock.Mock()
+                "ephemeral0.1",
+                lambda x: disk_name,
             ),
         )
 
@@ -115,7 +118,8 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.assertEqual(
             actual_partition_path,
             cc_mounts.sanitize_devname(
-                "ephemeral0", lambda x: disk_name, mock.Mock()
+                "ephemeral0",
+                lambda x: disk_name,
             ),
         )
 
@@ -126,27 +130,35 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.assertEqual(
             actual_partition_path,
             cc_mounts.sanitize_devname(
-                "ephemeral0.3", lambda x: disk_name, mock.Mock()
+                "ephemeral0.3",
+                lambda x: disk_name,
             ),
         )
 
     def test_transformer_returning_none_returns_none(self):
         self.assertIsNone(
             cc_mounts.sanitize_devname(
-                "ephemeral0", lambda x: None, mock.Mock()
+                "ephemeral0",
+                lambda x: None,
             )
         )
 
     def test_missing_device_returns_none(self):
         self.assertIsNone(
-            cc_mounts.sanitize_devname("/dev/sda", None, mock.Mock())
+            cc_mounts.sanitize_devname(
+                "/dev/sda",
+                None,
+            )
         )
 
     def test_missing_sys_returns_none(self):
         disk_path = "/dev/sda"
         self._makedirs(disk_path)
         self.assertIsNone(
-            cc_mounts.sanitize_devname(disk_path, None, mock.Mock())
+            cc_mounts.sanitize_devname(
+                disk_path,
+                None,
+            )
         )
 
     def test_existent_disk_but_missing_partition_returns_none(self):
@@ -154,14 +166,19 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.mock_existence_of_disk(disk_path)
         self.assertIsNone(
             cc_mounts.sanitize_devname(
-                "ephemeral0.1", lambda x: disk_path, mock.Mock()
+                "ephemeral0.1",
+                lambda x: disk_path,
             )
         )
 
     def test_network_device_returns_network_device(self):
         disk_path = "netdevice:/path"
         self.assertEqual(
-            disk_path, cc_mounts.sanitize_devname(disk_path, None, mock.Mock())
+            disk_path,
+            cc_mounts.sanitize_devname(
+                disk_path,
+                None,
+            ),
         )
 
     def test_device_aliases_remapping(self):
@@ -170,7 +187,7 @@ class TestSanitizeDevname(test_helpers.FilesystemMockingTestCase):
         self.assertEqual(
             disk_path,
             cc_mounts.sanitize_devname(
-                "mydata", lambda x: None, mock.Mock(), {"mydata": disk_path}
+                "mydata", lambda x: None, {"mydata": disk_path}
             ),
         )
 
@@ -239,7 +256,7 @@ class TestSwapFileCreation(test_helpers.FilesystemMockingTestCase):
         m_kernel_version.return_value = (4, 20)
         m_get_mount_info.return_value = ["", "xfs"]
 
-        cc_mounts.handle(None, self.cc, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, self.cc, self.mock_cloud, [])
         self.m_subp_subp.assert_has_calls(
             [
                 mock.call(
@@ -258,7 +275,7 @@ class TestSwapFileCreation(test_helpers.FilesystemMockingTestCase):
         m_kernel_version.return_value = (3, 18)
         m_get_mount_info.return_value = ["", "xfs"]
 
-        cc_mounts.handle(None, self.cc, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, self.cc, self.mock_cloud, [])
         self.m_subp_subp.assert_has_calls(
             [
                 mock.call(
@@ -284,7 +301,7 @@ class TestSwapFileCreation(test_helpers.FilesystemMockingTestCase):
         m_kernel_version.return_value = (4, 20)
         m_get_mount_info.return_value = ["", "btrfs"]
 
-        cc_mounts.handle(None, self.cc, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, self.cc, self.mock_cloud, [])
         self.m_subp_subp.assert_has_calls(
             [
                 mock.call(
@@ -310,7 +327,7 @@ class TestSwapFileCreation(test_helpers.FilesystemMockingTestCase):
         m_kernel_version.return_value = (5, 14)
         m_get_mount_info.return_value = ["", "ext4"]
 
-        cc_mounts.handle(None, self.cc, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, self.cc, self.mock_cloud, [])
         self.m_subp_subp.assert_has_calls(
             [
                 mock.call(
@@ -385,7 +402,7 @@ class TestFstabHandling(test_helpers.FilesystemMockingTestCase):
             "%s\tnone\tswap\tsw,comment=cloudconfig\t0\t0\n"
             % (self.swap_path,)
         )
-        cc_mounts.handle(None, {}, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, {}, self.mock_cloud, [])
         with open(cc_mounts.FSTAB_PATH, "r") as fd:
             fstab_new_content = fd.read()
             self.assertEqual(fstab_expected_content, fstab_new_content)
@@ -400,7 +417,7 @@ class TestFstabHandling(test_helpers.FilesystemMockingTestCase):
         with open(cc_mounts.FSTAB_PATH, "w") as fd:
             fd.write(fstab)
         cc = {"swap": ["filename: /swap.img", "size: 512", "maxsize: 512"]}
-        cc_mounts.handle(None, cc, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, cc, self.mock_cloud, [])
 
     def test_fstab_no_swap_device(self):
         """Ensure that cloud-init adds a discovered swap partition
@@ -415,7 +432,7 @@ class TestFstabHandling(test_helpers.FilesystemMockingTestCase):
         with open(cc_mounts.FSTAB_PATH, "w") as fd:
             fd.write(fstab_original_content)
 
-        cc_mounts.handle(None, {}, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, {}, self.mock_cloud, [])
 
         with open(cc_mounts.FSTAB_PATH, "r") as fd:
             fstab_new_content = fd.read()
@@ -433,7 +450,7 @@ class TestFstabHandling(test_helpers.FilesystemMockingTestCase):
         with open(cc_mounts.FSTAB_PATH, "w") as fd:
             fd.write(fstab_original_content)
 
-        cc_mounts.handle(None, {}, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, {}, self.mock_cloud, [])
 
         with open(cc_mounts.FSTAB_PATH, "r") as fd:
             fstab_new_content = fd.read()
@@ -454,7 +471,7 @@ class TestFstabHandling(test_helpers.FilesystemMockingTestCase):
         with open(cc_mounts.FSTAB_PATH, "w") as fd:
             fd.write(fstab_original_content)
 
-        cc_mounts.handle(None, {}, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, {}, self.mock_cloud, [])
 
         with open(cc_mounts.FSTAB_PATH, "r") as fd:
             fstab_new_content = fd.read()
@@ -474,7 +491,7 @@ class TestFstabHandling(test_helpers.FilesystemMockingTestCase):
         with open(cc_mounts.FSTAB_PATH, "r") as fd:
             fstab_new_content = fd.read()
             self.assertEqual(fstab_expected_content, fstab_new_content)
-        cc_mounts.handle(None, cc, self.mock_cloud, self.mock_log, [])
+        cc_mounts.handle(None, cc, self.mock_cloud, [])
         self.m_subp_subp.assert_has_calls(
             [
                 mock.call(["mount", "-a"]),
