@@ -1,6 +1,8 @@
 # This file is part of cloud-init. See LICENSE file for license information.
 
-from cloudinit import settings, sources, type_utils
+from unittest.mock import patch
+
+from cloudinit import importer, settings, sources, type_utils
 from cloudinit.sources import DataSource
 from cloudinit.sources import DataSourceAliYun as AliYun
 from cloudinit.sources import DataSourceAltCloud as AltCloud
@@ -80,21 +82,42 @@ class ExpectedDataSources(test_helpers.TestCase):
     deps_network = [sources.DEP_FILESYSTEM, sources.DEP_NETWORK]
     pkg_list = [type_utils.obj_name(sources)]
 
+    @patch.object(
+        importer,
+        "match_case_insensitive_module_name",
+        lambda name: f"DataSource{name}",
+    )
     def test_expected_default_local_sources_found(self):
         found = sources.list_sources(
-            self.builtin_list, self.deps_local, self.pkg_list
+            self.builtin_list,
+            self.deps_local,
+            self.pkg_list,
         )
         self.assertEqual(set(DEFAULT_LOCAL), set(found))
 
+    @patch.object(
+        importer,
+        "match_case_insensitive_module_name",
+        lambda name: f"DataSource{name}",
+    )
     def test_expected_default_network_sources_found(self):
         found = sources.list_sources(
-            self.builtin_list, self.deps_network, self.pkg_list
+            self.builtin_list,
+            self.deps_network,
+            self.pkg_list,
         )
         self.assertEqual(set(DEFAULT_NETWORK), set(found))
 
+    @patch.object(
+        importer,
+        "match_case_insensitive_module_name",
+        lambda name: f"DataSource{name}",
+    )
     def test_expected_nondefault_network_sources_found(self):
         found = sources.list_sources(
-            ["AliYun"], self.deps_network, self.pkg_list
+            ["AliYun"],
+            self.deps_network,
+            self.pkg_list,
         )
         self.assertEqual(set([AliYun.DataSourceAliYun]), set(found))
 
@@ -120,6 +143,3 @@ class TestDataSourceInvariants(test_helpers.TestCase):
             )
             self.assertNotEqual(ds.dsname, DataSource.dsname, fail_msg)
             self.assertIsNotNone(ds.dsname)
-
-
-# vi: ts=4 expandtab
