@@ -55,14 +55,12 @@ class TestCLI:
         data_d = tmpdir.join("data")
         link_d = tmpdir.join("link")
         FakeArgs = namedtuple("FakeArgs", ["action", "local", "mode"])
+        my_action = mock.Mock()
 
-        def myaction():
-            raise Exception("Should not call myaction")
-
-        myargs = FakeArgs((action, myaction), False, "bogusmode")
+        myargs = FakeArgs((action, my_action), False, "bogusmode")
         with pytest.raises(ValueError, match=match):
             cli.status_wrapper(name, myargs, data_d, link_d)
-        assert "Should not call myaction" not in caplog.text
+        assert [] == my_action.call_args_list
 
     def test_status_wrapper_init_local_writes_fresh_status_info(self, tmpdir):
         """When running in init-local mode, status_wrapper writes status.json.
@@ -149,7 +147,6 @@ class TestCLI:
             "analyze",
             "clean",
             "devel",
-            "dhclient-hook",
             "features",
             "init",
             "modules",
@@ -319,19 +316,6 @@ class TestCLI:
         assert "cc_ntp" == parseargs.name
         assert False is parseargs.report
 
-    @mock.patch("cloudinit.cmd.main.dhclient_hook.handle_args")
-    def test_dhclient_hook_subcommand(self, m_handle_args):
-        """The subcommand 'dhclient-hook' calls dhclient_hook with args."""
-        self._call_main(["cloud-init", "dhclient-hook", "up", "eth0"])
-        (name, parseargs) = m_handle_args.call_args_list[0][0]
-        assert "dhclient-hook" == name
-        assert "dhclient-hook" == parseargs.subcommand
-        assert "dhclient-hook" == parseargs.action[0]
-        assert False is parseargs.debug
-        assert False is parseargs.force
-        assert "up" == parseargs.event
-        assert "eth0" == parseargs.interface
-
     @mock.patch("cloudinit.cmd.main.main_features")
     def test_features_hook_subcommand(self, m_features):
         """The subcommand 'features' calls main_features with args."""
